@@ -16,14 +16,23 @@ def init_module_names():
 def get_module_name(filename):
     path = os.path.normpath(filename)
     if not path in file_to_module_name:
-        print('Cannot find %s module name in:' % path)
-        for k,v in file_to_module_name.items():
-            print(k, '=', v)
+        return filename
     return file_to_module_name.get(path, filename)
 
 class Generator(object):
     def __init__(self):
         init_module_names()
+        self.substitues = {}
+        self.imports = []
+
+    def set_mock_substitutes(self, substitutes):
+        self.substitues = substitutes
+
+    def set_extra_imports(self, imports):
+        self.imports = imports
+
+    def get_declared_module_name(self, runtime_module_name):
+        return self.substitues.get(runtime_module_name, runtime_module_name)
 
     def dump(self, file_name, module, functions):
         pass
